@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2006-2007 Peng Wu
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /*
@@ -125,6 +124,7 @@ const phrase_token_t token_min = 0;
 const phrase_token_t token_max = UINT_MAX;
 
 const char c_separate = '#';
+
 typedef guint32 table_offset_t;
 
 typedef double parameter_t;
@@ -135,22 +135,30 @@ typedef GArray * ChewingKeyRestVector;
 
 /* Array of phrase_token_t */
 typedef GArray * TokenVector;
-typedef TokenVector MatchResults;
+typedef TokenVector MatchResult;
 
 /* Array of lookup_constraint_t */
 typedef GArray * CandidateConstraints;
 
 typedef guint32 pinyin_option_t;
 
+typedef guint32 pinyin_standard_option_t;
+
+typedef guint32 pinyin_fuzzy_option_t;
+
+typedef guint32 pinyin_correct_option_t;
+
 typedef enum {
     /* for default tables. */
     RESERVED = 0,
     GB_DICTIONARY = 1,
+    TSI_DICTIONARY = 1,
     GBK_DICTIONARY = 2,
-    MERGED_DICTIONARY = 3,
-    ADDON_DICTIONARY = 4,
-    NETWORK_DICTIONARY = 5,
-    USER_DICTIONARY = 6,
+    OPENGRAM_DICTIONARY = 3,
+    MERGED_DICTIONARY = 4,
+    ADDON_DICTIONARY = 5,
+    NETWORK_DICTIONARY = 6,
+    USER_DICTIONARY = 7,
 } PHRASE_INDEX_LIBRARIES;
 
 G_END_DECLS
