@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2006-2007 Peng Wu
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef PHRASE_LOOKUP_H
@@ -46,11 +45,11 @@ private:
     const gfloat bigram_lambda;
     const gfloat unigram_lambda;
 
-    PhraseItem m_cache_phrase_item;
+    PhraseItem m_cached_phrase_item;
     SingleGram m_merged_single_gram;
 protected:
     //saved varibles
-    FacadePhraseTable2 * m_phrase_table;
+    FacadePhraseTable3 * m_phrase_table;
     FacadePhraseIndex * m_phrase_index;
     Bigram * m_system_bigram;
     Bigram * m_user_bigram;
@@ -77,7 +76,7 @@ protected:
 
     bool save_next_step(int next_step_pos, lookup_value_t * cur_value, lookup_value_t * next_step);
 
-    bool final_step(MatchResults & results);
+    bool final_step(MatchResult & result);
 public:
     /**
      * PhraseLookup::PhraseLookup:
@@ -91,7 +90,7 @@ public:
      *
      */
     PhraseLookup(const gfloat lambda,
-                 FacadePhraseTable2 * phrase_table,
+                 FacadePhraseTable3 * phrase_table,
                  FacadePhraseIndex * phrase_index,
                  Bigram * system_bigram,
                  Bigram * user_bigram);
@@ -116,7 +115,7 @@ public:
      * Note: this method only accepts the characters in phrase large table.
      *
      */
-    bool get_best_match(int sentence_length, ucs4_t sentence[], MatchResults & results);
+    bool get_best_match(int sentence_length, ucs4_t sentence[], MatchResult & result);
 
     /**
      * PhraseLookup::convert_to_utf8:
@@ -129,10 +128,10 @@ public:
      * Note: free the result_string by g_free.
      *
      */
-    bool convert_to_utf8(MatchResults results,
+    bool convert_to_utf8(MatchResult result,
                          /* out */ char * & result_string)
     {
-        return pinyin::convert_to_utf8(m_phrase_index, results,
+        return pinyin::convert_to_utf8(m_phrase_index, result,
                                        "\n", true, result_string);
     }
 };
