@@ -344,7 +344,7 @@ ChewingLengthIndexLevel::~ChewingLengthIndexLevel() {
 	    CASE(14);
 	    CASE(15);
 	default:
-	    assert(false);
+	    abort();
 	}
     }
 #undef CASE
@@ -389,7 +389,7 @@ int ChewingLengthIndexLevel::search(pinyin_option_t options, int phrase_length,
 	CASE(14);
 	CASE(15);
     default:
-	assert(false);
+	abort();
     }
 
 #undef CASE
@@ -545,7 +545,7 @@ int ChewingLengthIndexLevel::add_index(int phrase_length,
 	CASE(14);
 	CASE(15);
     default:
-	assert(false);
+	abort();
     }
 
 #undef CASE
@@ -599,7 +599,7 @@ int ChewingLengthIndexLevel::remove_index(int phrase_length,
 	CASE(14);
 	CASE(15);
     default:
-	assert(false);
+	abort();
     }
 
 #undef CASE
@@ -804,7 +804,7 @@ bool ChewingBitmapIndexLevel::store(MemoryChunk * new_chunk,
 bool ChewingLengthIndexLevel::load(MemoryChunk * chunk, table_offset_t offset,
                                    table_offset_t end) {
     char * begin = (char *) chunk->begin();
-    guint32 nindex = *((guint32 *)(begin + offset)); /* number of index */
+    guint32 nindex = chunk->get_content<guint32>(offset); /* number of index */
     table_offset_t * index = (table_offset_t *)
         (begin + offset + sizeof(guint32));
 
@@ -850,7 +850,7 @@ bool ChewingLengthIndexLevel::load(MemoryChunk * chunk, table_offset_t offset,
 	    CASE(14);
 	    CASE(15);
 	default:
-	    assert(false);
+	    abort();
 	}
 
 #undef CASE
@@ -910,7 +910,7 @@ bool ChewingLengthIndexLevel::store(MemoryChunk * new_chunk,
 	    CASE(14);
 	    CASE(15);
 	default:
-	    assert(false);
+	    abort();
 	}
 #undef CASE
 
@@ -1034,7 +1034,7 @@ bool ChewingLengthIndexLevel::mask_out(phrase_token_t mask,
 	    CASE(14);
 	    CASE(15);
 	default:
-	    assert(false);
+	    abort();
         }
     }
 #undef CASE
