@@ -4,19 +4,18 @@
  *  
  *  Copyright (C) 2006-2007 Peng Wu
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef PHRASE_INDEX_H
@@ -27,9 +26,12 @@
 #include "novel_types.h"
 #include "chewing_key.h"
 #include "pinyin_parser2.h"
-#include "pinyin_phrase2.h"
+#include "zhuyin_parser2.h"
+#include "pinyin_phrase3.h"
 #include "memory_chunk.h"
 #include "phrase_index_logger.h"
+#include "table_info.h"
+#include "unaligned_memory.h"
 
 /**
  * Phrase Index File Format
@@ -77,8 +79,8 @@ public:
      *
      */
     PhraseItem(){
-	m_chunk.set_size(phrase_item_header);
-	memset(m_chunk.begin(), 0, m_chunk.size());
+        m_chunk.set_size(phrase_item_header);
+        memset(m_chunk.begin(), 0, m_chunk.size());
     }
 
 #if 0
@@ -96,8 +98,8 @@ public:
      *
      */
     guint8 get_phrase_length(){
-	char * buf_begin = (char *)m_chunk.begin();
-	return (*(guint8 *)buf_begin);
+        char * buf_begin = (char *)m_chunk.begin();
+        return (*(guint8 *)buf_begin);
     }
 
     /**
@@ -108,8 +110,8 @@ public:
      *
      */
     guint8 get_n_pronunciation(){
-	char * buf_begin = ( char *) m_chunk.begin();
-	return (*(guint8 *)(buf_begin + sizeof(guint8)));
+        char * buf_begin = ( char *) m_chunk.begin();
+        return (*(guint8 *)(buf_begin + sizeof(guint8)));
     }
 
     /**
@@ -120,62 +122,57 @@ public:
      *
      */
     guint32 get_unigram_frequency(){
-	char * buf_begin = (char *)m_chunk.begin();
-	return (*(guint32 *)(buf_begin + sizeof(guint8) + sizeof(guint8)));
+        return m_chunk.get_content<guint32>(sizeof(guint8) + sizeof(guint8));
     }
 
     /**
      * PhraseItem::get_pronunciation_possibility:
-     * @options: the pinyin options.
      * @keys: the pronunciation keys.
      * @returns: the possibility of this phrase item pronounces the pinyin.
      *
      * Get the possibility of this phrase item pronounces the pinyin.
      *
      */
-    gfloat get_pronunciation_possibility(pinyin_option_t options,
-                                         ChewingKey * keys){
-	guint8 phrase_length = get_phrase_length();
-	guint8 npron = get_n_pronunciation();
-	size_t offset = phrase_item_header + phrase_length * sizeof (ucs4_t);
-	char * buf_begin = (char *)m_chunk.begin();
-	guint32 matched = 0, total_freq =0;
-	for ( int i = 0 ; i < npron ; ++i){
-	    char * chewing_begin = buf_begin + offset +
-		i * (phrase_length * sizeof(ChewingKey) + sizeof(guint32));
-	    guint32 * freq = (guint32 *)(chewing_begin +
-                                         phrase_length * sizeof(ChewingKey));
-	    total_freq += *freq;
-	    if ( 0 == pinyin_compare_with_ambiguities2
-                 (options,  keys,
-                  (ChewingKey *)chewing_begin,phrase_length) ){
-		matched += *freq;
-	    }
-	}
+    gfloat get_pronunciation_possibility(ChewingKey * keys){
+        guint8 phrase_length = get_phrase_length();
+        guint8 npron = get_n_pronunciation();
+        size_t offset = phrase_item_header + phrase_length * sizeof (ucs4_t);
+        char * buf_begin = (char *)m_chunk.begin();
+        guint32 matched = 0, total_freq =0;
+        for ( int i = 0 ; i < npron ; ++i){
+            char * chewing_begin = buf_begin + offset +
+                i * (phrase_length * sizeof(ChewingKey) + sizeof(guint32));
+
+            guint32 freq = UnalignedMemory<guint32>::load(chewing_begin +
+                                                          phrase_length * sizeof(ChewingKey));
+            total_freq += freq;
+            if ( 0 == pinyin_compare_with_tones(keys, (ChewingKey *)chewing_begin,
+                                                phrase_length) ){
+                matched += freq;
+            }
+        }
 
 #if 1
         /* an additional safe guard for chewing. */
-	if ( 0 == total_freq )
-	    return 0;
+        if ( 0 == total_freq )
+            return 0;
 #endif
 
-	/* used preprocessor to avoid zero freq, in gen_chewing_table. */
-	gfloat retval = matched / (gfloat) total_freq;
-	return retval;
+        /* used preprocessor to avoid zero freq, in gen_pinyin_table. */
+        gfloat retval = matched / (gfloat) total_freq;
+        return retval;
     }
 
     /**
      * PhraseItem::increase_pronunciation_possibility:
-     * @options: the pinyin options.
      * @keys: the pronunciation keys.
      * @delta: the delta to be added to the pronunciation keys.
      *
      * Add the delta to the pronunciation of the pronunciation keys.
      *
      */
-    void increase_pronunciation_possibility(pinyin_option_t options,
-				     ChewingKey * keys,
-				     gint32 delta);
+    void increase_pronunciation_possibility(ChewingKey * keys,
+                                            gint32 delta);
 
     /**
      * PhraseItem::get_phrase_string:
@@ -209,8 +206,8 @@ public:
      *
      */
     bool get_nth_pronunciation(size_t index, 
-			       /* out */ ChewingKey * keys,
-			       /* out */ guint32 & freq);
+                               /* out */ ChewingKey * keys,
+                               /* out */ guint32 & freq);
 
     /**
      * PhraseItem::add_pronunciation:
@@ -268,10 +265,10 @@ private:
         m_total_freq = 0;
         m_phrase_index.set_size(0);
         m_phrase_content.set_size(0);
-	if ( m_chunk ){
-	    delete m_chunk;
-	    m_chunk = NULL;
-	}
+        if ( m_chunk ){
+            delete m_chunk;
+            m_chunk = NULL;
+        }
     }
 
 public:
@@ -282,7 +279,7 @@ public:
      *
      */
     SubPhraseIndex():m_total_freq(0){
-	m_chunk = NULL;
+        m_chunk = NULL;
     }
 
     /**
@@ -292,7 +289,7 @@ public:
      *
      */
     ~SubPhraseIndex(){
-	reset();
+        reset();
     }
     
     /**
@@ -306,7 +303,7 @@ public:
      *
      */
     bool load(MemoryChunk * chunk, 
-	      table_offset_t offset, table_offset_t end);
+              table_offset_t offset, table_offset_t end);
 
     /**
      * SubPhraseIndex::store:
@@ -319,7 +316,7 @@ public:
      *
      */
     bool store(MemoryChunk * new_chunk, 
-	       table_offset_t offset, table_offset_t & end);
+               table_offset_t offset, table_offset_t & end);
 
     /**
      * SubPhraseIndex::diff:
@@ -450,8 +447,8 @@ public:
      *
      */
     FacadePhraseIndex(){
-	m_total_freq = 0;
-	memset(m_sub_phrase_indices, 0, sizeof(m_sub_phrase_indices));
+        m_total_freq = 0;
+        memset(m_sub_phrase_indices, 0, sizeof(m_sub_phrase_indices));
     }
 
     /**
@@ -461,25 +458,27 @@ public:
      *
      */
     ~FacadePhraseIndex(){
-	for ( size_t i = 0; i < PHRASE_INDEX_LIBRARY_COUNT; ++i){
-	    if ( m_sub_phrase_indices[i] ){
-		delete m_sub_phrase_indices[i];
-		m_sub_phrase_indices[i] = NULL;
-	    }
-	}
+        for ( size_t i = 0; i < PHRASE_INDEX_LIBRARY_COUNT; ++i){
+            if ( m_sub_phrase_indices[i] ){
+                delete m_sub_phrase_indices[i];
+                m_sub_phrase_indices[i] = NULL;
+            }
+        }
     }
 
     /**
      * FacadePhraseIndex::load_text:
      * @phrase_index: the index of sub phrase index to be loaded.
      * @infile: the textual format file of the phrase table.
+     * @type: the type of phonetic table.
      * @returns: whether the load operation is successful.
      *
      * Load one sub phrase index from the textual format file.
      * Note: load sub phrase index according to the config in future.
      *
      */
-    bool load_text(guint8 phrase_index, FILE * infile);
+    bool load_text(guint8 phrase_index, FILE * infile,
+                   TABLE_PHONETIC_TYPE type);
 
     /**
      * FacadePhraseIndex::load:
@@ -614,7 +613,7 @@ public:
      *
      */
     guint32 get_phrase_index_total_freq(){
-	return m_total_freq;
+        return m_total_freq;
     }
 
     /**
@@ -627,12 +626,12 @@ public:
      *
      */
     int add_unigram_frequency(phrase_token_t token, guint32 delta){
-	guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
-	SubPhraseIndex * sub_phrase = m_sub_phrase_indices[index];
-	if ( !sub_phrase )
-	    return ERROR_NO_SUB_PHRASE_INDEX;
-	m_total_freq += delta;
-	return sub_phrase->add_unigram_frequency(token, delta);
+        guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
+        SubPhraseIndex * sub_phrase = m_sub_phrase_indices[index];
+        if ( !sub_phrase )
+            return ERROR_NO_SUB_PHRASE_INDEX;
+        m_total_freq += delta;
+        return sub_phrase->add_unigram_frequency(token, delta);
     }
 
     /**
@@ -645,11 +644,11 @@ public:
      *
      */
     int get_phrase_item(phrase_token_t token, PhraseItem & item){
-	guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
-	SubPhraseIndex * sub_phrase = m_sub_phrase_indices[index];
-	if ( !sub_phrase )
-	    return ERROR_NO_SUB_PHRASE_INDEX;
-	return sub_phrase->get_phrase_item(token, item);
+        guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
+        SubPhraseIndex * sub_phrase = m_sub_phrase_indices[index];
+        if ( !sub_phrase )
+            return ERROR_NO_SUB_PHRASE_INDEX;
+        return sub_phrase->get_phrase_item(token, item);
     }
 
     /**
@@ -662,13 +661,13 @@ public:
      *
      */
     int add_phrase_item(phrase_token_t token, PhraseItem * item){
-	guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
-	SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
-	if ( !sub_phrase ){
-	    sub_phrase = new SubPhraseIndex;
-	}   
-	m_total_freq += item->get_unigram_frequency();
-	return sub_phrase->add_phrase_item(token, item);
+        guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
+        SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
+        if ( !sub_phrase ){
+            sub_phrase = new SubPhraseIndex;
+        }   
+        m_total_freq += item->get_unigram_frequency();
+        return sub_phrase->add_phrase_item(token, item);
     }
 
     /**
@@ -681,16 +680,16 @@ public:
      *
      */
     int remove_phrase_item(phrase_token_t token, PhraseItem * & item){
-	guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
-	SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
-	if ( !sub_phrase ){
-	    return ERROR_NO_SUB_PHRASE_INDEX;
-	}
-	int result = sub_phrase->remove_phrase_item(token, item);
-	if ( result )
-	    return result;
-	m_total_freq -= item->get_unigram_frequency();
-	return result;
+        guint8 index = PHRASE_INDEX_LIBRARY_INDEX(token);
+        SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
+        if ( !sub_phrase ){
+            return ERROR_NO_SUB_PHRASE_INDEX;
+        }
+        int result = sub_phrase->remove_phrase_item(token, item);
+        if ( result )
+            return result;
+        m_total_freq -= item->get_unigram_frequency();
+        return result;
     }
 
     /**
@@ -820,10 +819,10 @@ public:
      *
      */
     int create_sub_phrase(guint8 index) {
-	SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
-	if (sub_phrase) {
-	    return ERROR_ALREADY_EXISTS;
-	}
+        SubPhraseIndex * & sub_phrase = m_sub_phrase_indices[index];
+        if (sub_phrase) {
+            return ERROR_ALREADY_EXISTS;
+        }
 
         sub_phrase = new SubPhraseIndex;
 
