@@ -4,22 +4,25 @@
  *  
  *  Copyright (C) 2011 Peng Wu <alexepico@gmail.com>
  *  
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- *  
+ *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 #include <locale.h>
 #include "pinyin_internal.h"
@@ -29,23 +32,23 @@
 bool try_phrase_lookup(PhraseLookup * phrase_lookup,
                        ucs4_t * ucs4_str, glong ucs4_len){
     char * result_string = NULL;
-    MatchResults results = g_array_new(FALSE, FALSE, sizeof(phrase_token_t));
-    phrase_lookup->get_best_match(ucs4_len, ucs4_str, results);
+    MatchResult result = g_array_new(FALSE, FALSE, sizeof(phrase_token_t));
+    phrase_lookup->get_best_match(ucs4_len, ucs4_str, result);
 #if 0
-    for ( size_t i = 0; i < results->len; ++i) {
-        phrase_token_t * token = &g_array_index(results, phrase_token_t, i);
+    for (size_t i = 0; i < result->len; ++i) {
+        phrase_token_t * token = &g_array_index(result, phrase_token_t, i);
         if ( *token == null_token )
             continue;
         printf("%d:%d\t", i, *token);
     }
     printf("\n");
 #endif
-    phrase_lookup->convert_to_utf8(results, result_string);
+    phrase_lookup->convert_to_utf8(result, result_string);
     if (result_string)
         printf("%s\n", result_string);
     else
         fprintf(stderr, "Error: Un-segmentable sentence encountered!\n");
-    g_array_free(results, TRUE);
+    g_array_free(result, TRUE);
     g_free(result_string);
     return true;
 }
@@ -62,10 +65,8 @@ int main(int argc, char * argv[]){
     }
 
     /* init phrase table */
-    FacadePhraseTable2 phrase_table;
-    MemoryChunk * chunk = new MemoryChunk;
-    chunk->load("../../data/phrase_index.bin");
-    phrase_table.load(chunk, NULL);
+    FacadePhraseTable3 phrase_table;
+    phrase_table.load("../../data/phrase_index.bin", NULL);
 
     const pinyin_table_info_t * phrase_files =
         system_table_info.get_default_tables();
